﻿using System;
using System.IO;
using System.Windows.Forms;

namespace DownloadFavicon
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.downloadButton.Click += downloadButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Download 버튼 클릭시 처리하기 - downloadButton_Click(sender, e)

        /// <summary>
        /// Download 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void downloadButton_Click(object sender, EventArgs e)
        {
            #region 사이트 URL을 설정한다.

            string siteURL = this.siteURLTextBox.Text.Trim();

            if(string.IsNullOrWhiteSpace(siteURL))
            {
                MessageBox.Show("사이트 URL을 입력해 주시기 바랍니다.");

                this.siteURLTextBox.Focus();

                this.siteURLTextBox.SelectAll();

                return;
            }

            if(!siteURL.StartsWith("http://") && !siteURL.StartsWith("https://"))
            {
                MessageBox.Show("사이트 URL은 \"http://\" 또는 \"https://\" 문자열로 시작해야 합니다.");

                this.siteURLTextBox.Focus();

                this.siteURLTextBox.SelectAll();

                return;
            }

            #endregion
            #region 파비콘 URI를 설정한다.

            Uri favionUri = FaviconHelper.GetFaviconURL(siteURL);

            if(favionUri == null)
            {
                MessageBox.Show("입력한 사이트 URL로 파비콘 URL을 설정할 수 없습니다.");

                this.siteURLTextBox.Focus();

                this.siteURLTextBox.SelectAll();

                return;
            }

            #endregion
            #region 다운로드 경로를 설정한다.

            string downloadPath = this.downloadPathTextBox.Text.Trim();

            if(string.IsNullOrWhiteSpace(downloadPath))
            {
                MessageBox.Show("다운로드 경로를 입력해 주시기 바랍니다");

                this.downloadPathTextBox.Focus();

                this.downloadPathTextBox.SelectAll();

                return;
            }

            if(Directory.Exists(downloadPath))
            {
                try
                {
                    Directory.CreateDirectory(downloadPath);
                }
                catch
                {
                    MessageBox.Show("다운로드 경로 생성시 에러가 발생했습니다.");

                    this.downloadPathTextBox.Focus();

                    this.downloadPathTextBox.SelectAll();

                    return;
                }
            }

            #endregion

            string downloadFilePath = Path.Combine(downloadPath, favionUri.Host + ".ico");

            FaviconHelper.DownloadFaviconFile(siteURL, downloadFilePath);
        }

        #endregion
    }
}